@@ -24,9 +24,6 @@
 #ifndef __TRANSFER_H
 #define __TRANSFER_H
 
-#include <gnome-xml/tree.h>
-#include <gnome-xml/parser.h>
-
 typedef struct _TransStringCList TransStringCList;
 
 struct _TransStringCList
@@ -38,7 +35,7 @@ struct _TransStringCList
   gchar *clist;
 };
 
-void transfer_xml_to_gui(XstTool *tool, gpointer data);
-void transfer_gui_to_xml(XstTool *tool, gpointer data);
+void transfer_xml_to_gui(GstTool *tool, gpointer data);
+void transfer_gui_to_xml(GstTool *tool, gpointer data);
 
 #endif /* TRANSFER_H */
